==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/fr.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "enregistrement...",
    "saved!" : "enregistré!",
    "failed!" : "échec!",
    "Saved" : "Sauvegardé",
    "There was a problem saving your changes. Click to resume editing." : "Un problème est survenu lors de la sauvegarde de vos modifications. Cliquez pour continuer l'édition.",
    "An error occurred!" : "Une erreur est survenue !",
    "Edit" : "Éditer",
    "Mixed" : "Mélangé",
    "Preview" : "Aperçu",
    "New text file" : "Nouveau fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt",
    "You can not open a folder" : "Vous ne pouvez pas ouvrir ce dossier",
    "This file is too big to be opened. Please download the file instead." : "Ce fichier est trop volumineux pour être ouvert. Veuillez plutôt le télécharger.",
    "Cannot read the file." : "Impossible de lire le fichier.",
    "Invalid file path supplied." : "Chemin de fichier fourni non valide.",
    "The file is locked." : "Le fichier est verrouillé.",
    "An internal server error occurred." : "Une erreur interne au serveur est survenue.",
    "You can not write to a folder" : "Vous ne pouvez pas écrire dans ce dossier",
    "Cannot save file as it has been modified since opening" : "Impossible de sauvegarder le fichier, il a été modifié entre temps",
    "Insufficient permissions" : "Permissions insuffisantes",
    "File path not supplied" : "Chemin du fichier non fourni",
    "File mtime not supplied" : "mtime du fichier non fourni",
    "Text editor" : "Éditeur de texte",
    "Text file" : "Fichier texte"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/fr.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "enregistrement...",
    "saved!" : "enregistré!",
    "failed!" : "échec !",
    "Saved" : "Sauvegardé",
    "There was a problem saving your changes. Click to resume editing." : "Un problème est survenu lors de la sauvegarde de vos modifications. Cliquez pour continuer l'édition.",
    "An error occurred!" : "Une erreur est survenue !",
    "Edit" : "Éditer",
    "Mixed" : "Mélangé",
    "Preview" : "Aperçu",
    "New text file" : "Nouveau fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt",
    "You can not open a folder" : "Vous ne pouvez pas ouvrir ce dossier",
    "This file is too big to be opened. Please download the file instead." : "Ce fichier est trop volumineux pour être ouvert. Veuillez plutôt le télécharger.",
    "Cannot read the file." : "Impossible de lire le fichier.",
    "Invalid file path supplied." : "Chemin de fichier fourni non valide.",
    "The file is locked." : "Le fichier est verrouillé.",
    "An internal server error occurred." : "Une erreur interne au serveur est survenue.",
    "You can not write to a folder" : "Vous ne pouvez pas écrire dans ce dossier",
    "Cannot save file as it has been modified since opening" : "Impossible de sauvegarder le fichier, il a été modifié entre temps",
    "Insufficient permissions" : "Permissions insuffisantes",
    "File path not supplied" : "Chemin du fichier non fourni",
    "File mtime not supplied" : "mtime du fichier non fourni",
    "Share not found" : "Partage non trouvé",
    "You are not authorized to open this share" : "Vous n'êtes pas autorisé à ouvrir ce partage",
    "Invalid range request" : "Demande de plage non valide",
    "Text editor" : "Éditeur de texte"
},
"nplurals=2; plural=(n > 1);");
